@@ -2,16 +2,10 @@
 package version::vpp;
 use strict;
 
-use Exporter ();
-use Scalar::Util qw(isvstring reftype);
-use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS @REGEXS);
-$VERSION     = "0.56_03";
+use Scalar::Util;
+use vars qw ($VERSION @ISA @REGEXS);
+$VERSION     = "0.59_02";
 $VERSION     = eval $VERSION;
-@ISA         = qw (Exporter);
-#Give a hoot don't pollute, do not export more than needed by default
-@EXPORT      = qw (qv);
-@EXPORT_OK   = qw ();
-%EXPORT_TAGS = ();
 
 push @REGEXS, qr/
 	^v?	# optional leading 'v'
@@ -36,7 +30,8 @@ sub new
 	    $value = 'v'.$_[2];
 	}
 
-	if ( isvstring($value) ) {
+	my $eval = eval 'Scalar::Util::isvstring($value)';
+	if ( !$@ and $eval ) {
 	    $value = sprintf("v%vd",$value);
 	}
 	
@@ -364,7 +359,13 @@ sub is_alpha {
 sub qv {
     my ($value) = @_;
 
-    if ( isvstring($value) ) {
+    if ( $value =~ /\d+e-?\d+/ ) { # exponential notation
+	$value = sprintf("%.9f",$value);
+	$value =~ s/(0+)//;
+    }
+
+    my $eval = eval 'Scalar::Util::isvstring($value)';
+    if ( !$@ and $eval ) {
 	$value = sprintf("v%vd",$value);
     }
     else {
@@ -375,7 +376,7 @@ sub qv {
 
 sub _verify {
     my ($self) = @_;
-    if (   reftype($self) eq 'HASH'
+    if (   Scalar::Util::reftype($self) eq 'HASH'
 	&& exists $self->{version}
 	&& ref($self->{version}) eq 'ARRAY'
 	) {
@@ -386,37 +387,40 @@ sub _verify {
     }
 }
 
-local $^W; # shut up the 'redefined' warning for UNIVERSAL::VERSION
-no warnings 'redefine';
+# Thanks to Yitzchak Scott-Thoennes for this mode of operation
+{
+    local $^W;
+    *UNIVERSAL::VERSION = sub {
+	my ($obj, $req) = @_;
+	my $class = ref($obj) || $obj;
+	if ( $req =~ /\d+e-?\d+/ ) { # exponential notation
+	    $DB::single = 1;
+	    $req = sprintf("%.9f",$req);
+	    $req =~ s/(0+)$//;
+	}
+	no strict 'refs';
+	eval "require $class" unless %{"$class\::"}; # already existing
+	die "$class defines neither package nor VERSION--version check failed"
+	    if $@ or not %{"$class\::"};
+	
+	my $version = eval "\$$class\::VERSION";
+	die "$class does not define \$$class\::VERSION--version check failed"
+	    unless defined $version;
 
-package UNIVERSAL;
+	$version = version::vpp->new($version);
 
-sub VERSION {
-    my ($obj, $req) = @_;
-    my $class = ref($obj) || $obj;
-    no strict 'refs';
-    eval "require $class" unless %{"$class\::"}; # already existing
-    die "$class defines neither package nor VERSION--version check failed"
-        if $@ or not %{"$class\::"};
-    
-    my $version = eval "\$$class\::VERSION";
-    die "$class does not define \$$class\::VERSION--version check failed"
-        unless defined $version;
+	if ( defined $req ) {
+	    $req = version::vpp->new($req);
 
-    $version = version::vpp->new($version);
+	    die sprintf ("%s version %s (%s) required--".
+		     "this is only version %s (%s)", $class, 
+		     $req->numify, $req->normal,
+		     $version->numify, $version->normal)
+		if ( $req > $version ); 
+	}
 
-    if ( defined $req ) {
-	$req = version::vpp->new($req);
-
-	die sprintf ("%s version %s (%s) required--".
-                 "this is only version %s (%s)", $class, 
-		 $req->numify, $req->normal,
-		 $version->numify, $version->normal)
-	    if ( $req > $version ); 
-    }
-
-    return $version->numify;
+	return $version->numify;
+    };
 }
 
-
 1; #this line is important and will help the module return a true value
